# <img alt="atomate" src="docs_rst/_static/atomate_logo_small.png" width="250">

atomate is a software for computational materials science that contains pre-built workflows to compute and analyze the properties of materials.

- **Website (including documentation):** https://hackingmaterials.github.io/atomate/
- **Help/Support:** https://groups.google.com/forum/#!forum/atomate
- **Source:** https://github.com/hackingmaterials/atomate

If you find atomate useful, please encourage its development by citing the following paper in your research output:

```
Mathew, K., Montoya, J. H., Faghaninia, A., Dwarakanath, S., Aykol, 
M., Tang, H., Chu, I., Smidt, T., Bocklund, B., Horton, M., Dagdelen, 
J., Wood, B., Liu, Z.-K., Neaton, J., Ong, S. P., Persson, K., Jain, 
A., Atomate: A high-level interface to generate, execute, and analyze 
computational materials science workflows. Comput. Mater. Sci. 139, 
140-152 (2017).
```
